def Lsegitiga(alas:float, tinggi:float) -> float :
    luas = (alas*tinggi)/2
    return luas

def Lpersegi(panjang:float, lebar:float) -> float :
    luas = panjang * lebar
    return luas



def Vlimas(panjang:float, lebar:float, tinggi:float) -> float :
    volume = (panjang * lebar * tinggi)/3
    return volume

def Vbalok(panjang:float, lebar:float, tinggi:float) -> float:
    volume = panjang*lebar*tinggi
    return volume


from setuptools import find_packages, setup

setup(
    name='ngitung',
    packages = find_packages(include=['ngitung']),
    version='0.1.0',
    description='Uji Coba Library Python Sederhana',
    author = 'Mahasin',
    author_email='mmasadar@gmail.com',
    license='MIT',
    install_requires=[],
    setup_requires=['pytest-runner'],
    tests_require=['pytest==4.4.1'],
    test_suite='tests',
)